#
# spec file for package python-lazy
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-lazy
Version:        1.6
Release:        2.1
Summary:        Lazy attributes for Python objects
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://github.com/stefanholek/lazy
Source:         https://files.pythonhosted.org/packages/source/l/lazy/lazy-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
BuildArch:      noarch
%python_subpackages

%description
Lazy attributes are computed attributes that are evaluated only once,
the first time they are used. Subsequent uses return the results of
the first call. They come handy when code should run
 * late, i.e. just before it is needed, and
 * once, i.e. not twice, in the lifetime of an object.
You can think of it as deferred initialization. The possibilities are
endless.

%prep
%setup -q -n lazy-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest discover -v

%files %{python_files}
%doc README.rst CHANGES.rst
%license LICENSE
%{python_sitelib}/lazy
%{python_sitelib}/lazy-%{version}*-info

%changelog
* Fri May 30 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Thu Dec  7 2023 Dirk Müller <dmueller@suse.com>
- update to 1.6:
  * Implement ``lazy.__set_name__()`` which helps in cases like
  * ``foo=lazy(_foo)``.
  * Pin sphinx and sphinx-rtd-theme versions in docs extra.
  * Fix stray characters in keywords.
* Fri Jun  9 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Wed Jan 18 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.5
  * Allow type checkers to infer the type of a lazy attribute
  * Add Python 3.8-3.11 to tox.ini. Remove old Python versions
  * Replace deprecated python setup.py test in tox.ini
  * Remove deprecated test_suite from setup.py
  * Move metadata to setup.cfg and add a pyproject.toml file
  * Include tests in sdist but not in wheel
- use .tar.gz instead of .zip for better compression ratio
* Wed May 26 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
* Thu Feb 28 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.4:
  * Add MANIFEST.in. [stefan]
  * Release as universal wheel. [stefan]
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu May 10 2018 toddrme2178@gmail.com
- Use license tag
* Sat Oct  7 2017 arun@gmx.de
- initial package
